/**
 *
 */
package de.intevation.gnv.artifacts.ressource;

import java.util.Locale;
import java.util.ResourceBundle;

import org.apache.log4j.Logger;

/**
 * @author Tim Englich <tim.englich@intevation.de>
 *
 */
public class RessourceFactory {

    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger log = Logger.getLogger(RessourceFactory.class);
    
    /**
     * The singleton Instance of this Factory.
     */
    private static RessourceFactory instance = null;

    private static String RESSOURCE_BASE_ID = "artifact.ressource.dir";
    
    private static String ressourceName = "artifactMessages";
    
    private String ressourceDir = null;
    
    private Locale[] supportedLocales = null;
    /**
     * Basic-Constructor of this Class
     */
    private RessourceFactory() {
        super();
        ressourceDir = System.getProperty(RESSOURCE_BASE_ID);
        if (ressourceDir == null){
            ressourceDir = "de/intevation/gnv/artifacts/ressource";
        }
        supportedLocales =  new Locale[1];
        supportedLocales[0] = Locale.GERMAN;
    }

    /**
     * This Method provides an singleton Instance of this Class.
     * @return an singleton Instance of this Class
     */
    public static RessourceFactory getInstance(){
        if (instance == null){
            instance = new RessourceFactory();
        }
        return instance;
    }
    
    /**
     * Deliveres the translated Value for an Key to an given Language
     * @param locale The choosen locale
     * @param key the key
     * @param defaultValue the Value that should be returned.
     * @return the translated Value
     */
    public String getRessource(Locale locale, String key, String defaultValue){
        ResourceBundle rb = ResourceBundle.getBundle(ressourceDir+"/"+ressourceName, locale);
        try {
            return rb.getString(key);
        } catch (Exception e) {
            log.warn(e.getMessage());
            return defaultValue;
        }
    }
    
    public Locale[] getSupportedLocales(){
      return supportedLocales;
    }
}
